FronteggException class sealed

Represents an exception that occurs within the Frontegg authentication system.

Implemented types
Implementers

Constructors

FronteggException.fromFailureReason(String failureReason, {String? message})
factory

Properties

failureReason String
The error message describing the exception, if available.
final
hashCode int
The hash code for this object.
no setterinherited
message String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited