FronteggFlutter class

Constructors

FronteggFlutter()

Properties

currentState FronteggState
Gets the current state of the Frontegg instance.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stateChanged Stream<FronteggState>
A stream that emits changes to the FronteggState.
no setter

Methods

customSocialLogin({required String id, bool ephemeralSession = true, Map<String, String>? additionalQueryParams}) Future<void>
Initiates a custom social login using a unique identifier.
directLogin({required String url, bool ephemeralSession = true, Map<String, String>? additionalQueryParams}) Future<void>
Initiates a direct login using a provided URL.
directLoginAction(String type, String data, {bool ephemeralSession = true, Map<String, String>? additionalQueryParams}) Future<void>
Performs a direct login action.
dispose() Future<void>
Cancels the subscription to the state stream.
forceStateUpdate() Future<void>
Forces a state update in hosted mode.
getConstants() Future<FronteggConstants>
Fetches the Frontegg constants from the platform.
getFeatureEntitlement(String featureKey) Future<Entitlement>
Returns the Entitlement for the given feature key.
getPermissionEntitlement(String permissionKey) Future<Entitlement>
Returns the Entitlement for the given permission key.
isSteppedUp({Duration? maxAge}) Future<bool>
Checks whether step-up authentication has been performed and is still valid.
loadEntitlements({bool forceRefresh = false}) Future<bool>
Manually triggers entitlements loading on the native SDKs.
login({String? loginHint}) Future<void>
Logs in the user by initiating the authentication process.
loginWithPasskeys() Future<void>
Logs in the user using passkeys.
logout() Future<void>
Logs out the user and clears user-related data.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openAdminPortal() Future<void>
Opens the embedded Frontegg Admin Portal.
refreshToken() Future<bool>
Refreshes the token if needed.
registerPasskeys() Future<void>
Registers passkeys for the user.
requestAuthorize({required String refreshToken, String? deviceTokenCookie}) Future<FronteggUser?>
Initiates authorization request using a refresh token.
socialLogin({required FronteggSocialProvider provider, bool ephemeralSession = true, Map<String, String>? additionalQueryParams}) Future<void>
Initiates a social login using the specified social provider.
stepUp({Duration? maxAge}) Future<void>
Initiates a step-up authentication process.
switchTenant(String tenantId) Future<void>
Switches the user's tenant.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited