customSocialLogin method

Future<void> customSocialLogin({
  1. required String id,
  2. bool ephemeralSession = true,
  3. Map<String, String>? additionalQueryParams,
})

Initiates a custom social login using a unique identifier.

This method starts the authentication process with a custom social login, using the provided unique identifier.

  • id: The unique identifier for the custom social login.
  • ephemeralSession: (Optional) Determines whether the session should be ephemeral (not shared with the default browser). Defaults to true.
  • additionalQueryParams: (Optional) A map containing additional query parameters. Defaults to null.

Throws a FronteggException if the login process encounters a platform-specific error.

Returns a Future that completes when the custom social login process is finished.

Implementation

Future<void> customSocialLogin({
  required String id,
  bool ephemeralSession = true,
  Map<String, String>? additionalQueryParams,
}) =>
    _runAction(() async {
      await FronteggPlatform.instance.customSocialLogin(
        id: id,
        ephemeralSession: ephemeralSession,
        additionalQueryParams: additionalQueryParams,
      );
    });