FronteggSocialProvider enum

Enum representing supported social authentication providers in Frontegg.

Inheritance
Available extensions

Values

google → const FronteggSocialProvider

Google authentication provider.

const FronteggSocialProvider("google")
linkedin → const FronteggSocialProvider

LinkedIn authentication provider.

const FronteggSocialProvider("linkedin")
facebook → const FronteggSocialProvider

Facebook authentication provider.

const FronteggSocialProvider("facebook")
github → const FronteggSocialProvider

GitHub authentication provider.

const FronteggSocialProvider("github")
apple → const FronteggSocialProvider

Apple authentication provider.

const FronteggSocialProvider("apple")
microsoft → const FronteggSocialProvider

Microsoft authentication provider.

const FronteggSocialProvider("microsoft")
slack → const FronteggSocialProvider

Slack authentication provider.

const FronteggSocialProvider("slack")

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
The string representation of the provider type.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<FronteggSocialProvider>
A constant List of the values in this enum, in order of their declaration.