FronteggTenant class

Represents a tenant in the Frontegg authentication system.

Constructors

FronteggTenant({required String id, required String name, String? creatorEmail, String? creatorName, required String tenantId, required String vendorId, required bool isReseller, required String metadata, required DateTime createdAt, required DateTime updatedAt, String? website})
Creates a FronteggTenant instance with the given parameters.
const
FronteggTenant.fromMap(Map<Object?, Object?> map)
factory

Properties

createdAt DateTime
The date and time when the tenant was created.
final
creatorEmail String?
Email of the tenant's creator, if available.
final
creatorName String?
Name of the tenant's creator, if available.
final
hashCode int
The hash code for this object.
no setteroverride
id String
Unique identifier for the tenant.
final
isReseller bool
Indicates whether the tenant is a reseller.
final
metadata String
Metadata associated with the tenant.
final
name String
Name of the tenant.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tenantId String
Unique identifier for the tenant within the Frontegg system.
final
updatedAt DateTime
The date and time when the tenant was last updated.
final
vendorId String
Unique identifier for the vendor associated with this tenant.
final
website String?
The website URL associated with the tenant, if available.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override