FronteggUserRole class

Represents a user role in the Frontegg authentication system.

Constructors

FronteggUserRole({required String id, required String key, required bool isDefault, required String name, String? description, required List<String> permissions, String? tenantId, required String vendorId, required DateTime createdAt, required DateTime updatedAt})
Creates a FronteggUserRole instance with the given parameters.
const
FronteggUserRole.fromMap(Map<Object?, Object?> map)
factory

Properties

createdAt DateTime
The date and time when the role was created.
final
description String?
Optional description of the role.
final
hashCode int
The hash code for this object.
no setteroverride
id String
Unique identifier for the role.
final
isDefault bool
Indicates whether this role is the default role.
final
key String
Unique key representing the role.
final
name String
Name of the role.
final
permissions List<String>
List of permission identifiers associated with this role.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tenantId String?
Optional tenant ID this role is associated with.
final
updatedAt DateTime
The date and time when the role was last updated.
final
vendorId String
Unique identifier for the vendor associated with this role.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override