KeyNotFoundSharedPreferencesException class

Exception thrown when a key is not found in SharedPreferences storage. This typically occurs when trying to access stored authentication data that doesn't exist.

Inheritance

Constructors

KeyNotFoundSharedPreferencesException([String? message])
const

Properties

failureReason String
The error message describing the exception, if available.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
message String?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited