FronteggConstants class
A class containing constants for configuring Frontegg authentication.
Constructors
- FronteggConstants({required String baseUrl, required String clientId, String? applicationId, bool? useAssetsLinks, bool? useChromeCustomTabs, required String bundleId})
-
Creates a FronteggConstants instance with required parameters.
const
-
FronteggConstants.fromMap(Map<
Object?, Object?> map) -
factory
Properties
- applicationId → String?
-
The optional application ID, if applicable.
final
- baseUrl → String
-
The base URL of the Frontegg authentication server.
final
- bundleId → String
-
The bundle ID of the application, used for identifying the app.
final
- clientId → String
-
The client ID associated with the Frontegg application.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- useAssetsLinks → bool?
-
Whether to use asset links for authentication. Defaults to
null(not set).final - useChromeCustomTabs → bool?
-
Whether to use Chrome Custom Tabs for authentication. Defaults to
null(not set).final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override