registerPasskeys method
Registers passkeys for the user.
This method attempts to register passkeys and may throw an exception if an error occurs.
If an exception occurs during registration, a FronteggException is thrown with the error message.
Throws a FronteggException if the login process encounters a platform-specific error.
Returns a Future that completes when the registration process is finished.
Implementation
Future<void> registerPasskeys() => _runAction(() async {
await FronteggPlatform.instance.registerPasskeys();
});